@@ -1,5 +1,6 @@
 import six
 
+from samtranslator.model.intrinsics import make_conditional
 from samtranslator.model.naming import GeneratedLogicalId
 from samtranslator.plugins.api.implicit_api_plugin import ImplicitApiPlugin
 from samtranslator.public.open_api import OpenApiEditor
@@ -88,6 +89,8 @@ class ImplicitHttpApiPlugin(ImplicitApiPlugin):
                 method_conditions[method] = condition
 
             self._add_api_to_swagger(logicalId, event_properties, template)
+            if "RouteSettings" in event_properties:
+                self._add_route_settings_to_api(logicalId, event_properties, template, condition)
             api_events[logicalId] = event
 
         # We could have made changes to the Events structure. Write it back to function
@@ -116,6 +119,46 @@ class ImplicitHttpApiPlugin(ImplicitApiPlugin):
         """
         return editor.openapi
 
+    def _get_api_resource_type_name(self):
+        """
+        Returns the type of API resource
+        """
+        return "AWS::Serverless::HttpApi"
+
+    def _add_route_settings_to_api(self, event_id, event_properties, template, condition):
+        """
+        Adds the RouteSettings for this path/method from the given event to the RouteSettings configuration
+        on the AWS::Serverless::HttpApi that this refers to.
+
+        :param string event_id: LogicalId of the event
+        :param dict event_properties: Properties of the event
+        :param SamTemplate template: SAM Template to search for Serverless::HttpApi resources
+        :param string condition: Condition on this HttpApi event (if any)
+        """
+
+        api_id = self._get_api_id(event_properties)
+        resource = template.get(api_id)
+
+        path = event_properties["Path"]
+        method = event_properties["Method"]
+
+        # Route should be in format "METHOD /path" or just "/path" if the ANY method is used
+        route = "{} {}".format(method.upper(), path)
+        if method == OpenApiEditor._X_ANY_METHOD:
+            route = path
+
+        # Handle Resource-level conditions if necessary
+        api_route_settings = resource.properties.get("RouteSettings", {})
+        event_route_settings = event_properties.get("RouteSettings", {})
+        if condition:
+            event_route_settings = make_conditional(condition, event_properties.get("RouteSettings", {}))
+
+        # Merge event-level and api-level RouteSettings properties
+        api_route_settings.setdefault(route, {})
+        api_route_settings[route].update(event_route_settings)
+        resource.properties["RouteSettings"] = api_route_settings
+        template.set(api_id, resource)
+
 
 class ImplicitHttpApiResource(SamResource):
     """
